#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stm-containers
version:              1.2.2
visibility:           public
id:                   stm-containers-1.2.2-ImRytgGzpwD6j3sGQ7LQ10
key:                  stm-containers-1.2.2-ImRytgGzpwD6j3sGQ7LQ10
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/stm-containers
synopsis:             Containers for STM
description:
    This library is based on an STM-specialized implementation of
    Hash Array Mapped Trie.
    It provides efficient implementations of @Map@, @Set@
    and other data structures,
    which starting from version @1@ perform even better than their counterparts from \"unordered-containers\",
    but also scale well on concurrent access patterns.
    .
    For details on performance of the library, which are a bit outdated, see
    <http://nikita-volkov.github.io/stm-containers/ this blog post>.

category:             Data Structures, STM, Concurrency
abi:                  3bb61eadcbdf08a2b8fb3f39d9d4b2a7
exposed:              True
exposed-modules:
    StmContainers.Bimap StmContainers.Map StmContainers.Multimap
    StmContainers.Set

hidden-modules:       StmContainers.Prelude
import-dirs:          /usr/lib/ghc-9.6.6/site-local/stm-containers-1.2.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stm-containers-1.2.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stm-containers-1.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stm-containers
hs-libraries:         HSstm-containers-1.2.2-ImRytgGzpwD6j3sGQ7LQ10
depends:
    base-4.18.2.1 deferred-folds-0.9.18.10-7Qy7YAuzRMZGNMkJd3lzL7
    focus-1.0.3.2-K4r8d6TYSaL8JgI7TgFd9X
    hashable-1.4.7.0-KYRxVQLzygQHnYjqLKyJPN
    list-t-1.0.5.7-5wiNHt4HfJY6yigEbdj2d7
    stm-hamt-1.2.2.1-CvMFNVdzUTb3PaB2fCk2Tu transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-stm-containers/html/stm-containers.haddock

haddock-html:         /usr/share/doc/haskell-stm-containers/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

